==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/TaskStep.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) A single step within a task.
 * <p>
 * The step could either be  the execution of a
 * shell command or execution of a sub-task, by name.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.449Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.TaskStep")
@software.amazon.jsii.Jsii.Proxy(TaskStep.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface TaskStep extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.TaskStepOptions {

    /**
     * (experimental) The name of a built-in task to execute.
     * <p>
     * Built-in tasks are node.js programs baked into the projen module and as
     * component runtime helpers.
     * <p>
     * The name is a path relative to the projen lib/ directory (without the .task.js extension).
     * For example, if your built in builtin task is under <code>src/release/resolve-version.task.ts</code>,
     * then this would be <code>release/resolve-version</code>.
     * <p>
     * Default: - do not execute a builtin task
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getBuiltin() {
        return null;
    }

    /**
     * (experimental) Shell command to execute.
     * <p>
     * Default: - don't execute a shell command
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getExec() {
        return null;
    }

    /**
     * (experimental) Print a message.
     * <p>
     * Default: - don't say anything
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getSay() {
        return null;
    }

    /**
     * (experimental) Subtask to execute.
     * <p>
     * Default: - don't spawn a subtask
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getSpawn() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link TaskStep}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TaskStep}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<TaskStep> {
        java.lang.String builtin;
        java.lang.String exec;
        java.lang.String say;
        java.lang.String spawn;
        java.lang.String cwd;
        java.lang.String name;

        /**
         * Sets the value of {@link TaskStep#getBuiltin}
         * @param builtin The name of a built-in task to execute.
         *                Built-in tasks are node.js programs baked into the projen module and as
         *                component runtime helpers.
         *                <p>
         *                The name is a path relative to the projen lib/ directory (without the .task.js extension).
         *                For example, if your built in builtin task is under <code>src/release/resolve-version.task.ts</code>,
         *                then this would be <code>release/resolve-version</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder builtin(java.lang.String builtin) {
            this.builtin = builtin;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getExec}
         * @param exec Shell command to execute.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder exec(java.lang.String exec) {
            this.exec = exec;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getSay}
         * @param say Print a message.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder say(java.lang.String say) {
            this.say = say;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getSpawn}
         * @param spawn Subtask to execute.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder spawn(java.lang.String spawn) {
            this.spawn = spawn;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getCwd}
         * @param cwd The working directory for this step.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cwd(java.lang.String cwd) {
            this.cwd = cwd;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getName}
         * @param name Step name.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TaskStep}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public TaskStep build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link TaskStep}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TaskStep {
        private final java.lang.String builtin;
        private final java.lang.String exec;
        private final java.lang.String say;
        private final java.lang.String spawn;
        private final java.lang.String cwd;
        private final java.lang.String name;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.builtin = software.amazon.jsii.Kernel.get(this, "builtin", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.exec = software.amazon.jsii.Kernel.get(this, "exec", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.say = software.amazon.jsii.Kernel.get(this, "say", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.spawn = software.amazon.jsii.Kernel.get(this, "spawn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.cwd = software.amazon.jsii.Kernel.get(this, "cwd", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.builtin = builder.builtin;
            this.exec = builder.exec;
            this.say = builder.say;
            this.spawn = builder.spawn;
            this.cwd = builder.cwd;
            this.name = builder.name;
        }

        @Override
        public final java.lang.String getBuiltin() {
            return this.builtin;
        }

        @Override
        public final java.lang.String getExec() {
            return this.exec;
        }

        @Override
        public final java.lang.String getSay() {
            return this.say;
        }

        @Override
        public final java.lang.String getSpawn() {
            return this.spawn;
        }

        @Override
        public final java.lang.String getCwd() {
            return this.cwd;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getBuiltin() != null) {
                data.set("builtin", om.valueToTree(this.getBuiltin()));
            }
            if (this.getExec() != null) {
                data.set("exec", om.valueToTree(this.getExec()));
            }
            if (this.getSay() != null) {
                data.set("say", om.valueToTree(this.getSay()));
            }
            if (this.getSpawn() != null) {
                data.set("spawn", om.valueToTree(this.getSpawn()));
            }
            if (this.getCwd() != null) {
                data.set("cwd", om.valueToTree(this.getCwd()));
            }
            if (this.getName() != null) {
                data.set("name", om.valueToTree(this.getName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.TaskStep"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TaskStep.Jsii$Proxy that = (TaskStep.Jsii$Proxy) o;

            if (this.builtin != null ? !this.builtin.equals(that.builtin) : that.builtin != null) return false;
            if (this.exec != null ? !this.exec.equals(that.exec) : that.exec != null) return false;
            if (this.say != null ? !this.say.equals(that.say) : that.say != null) return false;
            if (this.spawn != null ? !this.spawn.equals(that.spawn) : that.spawn != null) return false;
            if (this.cwd != null ? !this.cwd.equals(that.cwd) : that.cwd != null) return false;
            return this.name != null ? this.name.equals(that.name) : that.name == null;
        }

        @Override
        public final int hashCode() {
            int result = this.builtin != null ? this.builtin.hashCode() : 0;
            result = 31 * result + (this.exec != null ? this.exec.hashCode() : 0);
            result = 31 * result + (this.say != null ? this.say.hashCode() : 0);
            result = 31 * result + (this.spawn != null ? this.spawn.hashCode() : 0);
            result = 31 * result + (this.cwd != null ? this.cwd.hashCode() : 0);
            result = 31 * result + (this.name != null ? this.name.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/TaskStep.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) A single step within a task.
 * <p>
 * The step could either be  the execution of a
 * shell command or execution of a sub-task, by name.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.157Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.TaskStep")
@software.amazon.jsii.Jsii.Proxy(TaskStep.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface TaskStep extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.TaskStepOptions {

    /**
     * (experimental) The name of a built-in task to execute.
     * <p>
     * Built-in tasks are node.js programs baked into the projen module and as
     * component runtime helpers.
     * <p>
     * The name is a path relative to the projen lib/ directory (without the .task.js extension).
     * For example, if your built in builtin task is under <code>src/release/resolve-version.task.ts</code>,
     * then this would be <code>release/resolve-version</code>.
     * <p>
     * Default: - do not execute a builtin task
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getBuiltin() {
        return null;
    }

    /**
     * (experimental) Shell command to execute.
     * <p>
     * Default: - don't execute a shell command
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getExec() {
        return null;
    }

    /**
     * (experimental) Print a message.
     * <p>
     * Default: - don't say anything
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getSay() {
        return null;
    }

    /**
     * (experimental) Subtask to execute.
     * <p>
     * Default: - don't spawn a subtask
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getSpawn() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link TaskStep}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TaskStep}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<TaskStep> {
        java.lang.String builtin;
        java.lang.String exec;
        java.lang.String say;
        java.lang.String spawn;
        java.util.List<java.lang.String> args;
        java.lang.String condition;
        java.lang.String cwd;
        java.util.Map<java.lang.String, java.lang.String> env;
        java.lang.String name;
        java.lang.Boolean receiveArgs;

        /**
         * Sets the value of {@link TaskStep#getBuiltin}
         * @param builtin The name of a built-in task to execute.
         *                Built-in tasks are node.js programs baked into the projen module and as
         *                component runtime helpers.
         *                <p>
         *                The name is a path relative to the projen lib/ directory (without the .task.js extension).
         *                For example, if your built in builtin task is under <code>src/release/resolve-version.task.ts</code>,
         *                then this would be <code>release/resolve-version</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder builtin(java.lang.String builtin) {
            this.builtin = builtin;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getExec}
         * @param exec Shell command to execute.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder exec(java.lang.String exec) {
            this.exec = exec;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getSay}
         * @param say Print a message.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder say(java.lang.String say) {
            this.say = say;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getSpawn}
         * @param spawn Subtask to execute.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder spawn(java.lang.String spawn) {
            this.spawn = spawn;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getArgs}
         * @param args A list of fixed arguments always passed to the step.
         *             Useful to re-use existing tasks without having to re-define the whole task.\
         *             Fixed args are always passed to the step, even if <code>receiveArgs</code> is <code>false</code>
         *             and are always passed before any args the task is called with.
         *             <p>
         *             If the step executes a shell commands, args are passed through at the end of the <code>exec</code> shell command.\
         *             The position of the args can be changed by including the marker <code>$&#64;</code> inside the command string.
         *             <p>
         *             If the step spawns a subtask, args are passed to the subtask.
         *             The subtask must define steps receiving args for this to have any effect.
         *             <p>
         *             If the step calls a builtin script, args are passed to the script.
         *             It is up to the script to use or discard the arguments.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder args(java.util.List<java.lang.String> args) {
            this.args = args;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getCondition}
         * @param condition A shell command which determines if the this step should be executed.
         *                  If
         *                  the program exits with a zero exit code, the step will be executed. A non-zero
         *                  code means the step will be skipped (subsequent task steps will still be evaluated/executed).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder condition(java.lang.String condition) {
            this.condition = condition;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getCwd}
         * @param cwd The working directory for this step.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cwd(java.lang.String cwd) {
            this.cwd = cwd;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getEnv}
         * @param env Defines environment variables for the execution of this step (<code>exec</code> and <code>builtin</code> only).
         *            Values in this map can be simple, literal values or shell expressions that will be evaluated at runtime e.g. <code>$(echo "foo")</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder env(java.util.Map<java.lang.String, java.lang.String> env) {
            this.env = env;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getName}
         * @param name Step name.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link TaskStep#getReceiveArgs}
         * @param receiveArgs Should this step receive args passed to the task.
         *                    If <code>true</code>, args are passed through at the end of the <code>exec</code> shell command.\
         *                    The position of the args can be changed by including the marker <code>$&#64;</code> inside the command string.
         *                    <p>
         *                    If the step spawns a subtask, args are passed to the subtask.
         *                    The subtask must define steps receiving args for this to have any effect.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder receiveArgs(java.lang.Boolean receiveArgs) {
            this.receiveArgs = receiveArgs;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TaskStep}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public TaskStep build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link TaskStep}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TaskStep {
        private final java.lang.String builtin;
        private final java.lang.String exec;
        private final java.lang.String say;
        private final java.lang.String spawn;
        private final java.util.List<java.lang.String> args;
        private final java.lang.String condition;
        private final java.lang.String cwd;
        private final java.util.Map<java.lang.String, java.lang.String> env;
        private final java.lang.String name;
        private final java.lang.Boolean receiveArgs;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.builtin = software.amazon.jsii.Kernel.get(this, "builtin", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.exec = software.amazon.jsii.Kernel.get(this, "exec", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.say = software.amazon.jsii.Kernel.get(this, "say", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.spawn = software.amazon.jsii.Kernel.get(this, "spawn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.args = software.amazon.jsii.Kernel.get(this, "args", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.condition = software.amazon.jsii.Kernel.get(this, "condition", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.cwd = software.amazon.jsii.Kernel.get(this, "cwd", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.env = software.amazon.jsii.Kernel.get(this, "env", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.receiveArgs = software.amazon.jsii.Kernel.get(this, "receiveArgs", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.builtin = builder.builtin;
            this.exec = builder.exec;
            this.say = builder.say;
            this.spawn = builder.spawn;
            this.args = builder.args;
            this.condition = builder.condition;
            this.cwd = builder.cwd;
            this.env = builder.env;
            this.name = builder.name;
            this.receiveArgs = builder.receiveArgs;
        }

        @Override
        public final java.lang.String getBuiltin() {
            return this.builtin;
        }

        @Override
        public final java.lang.String getExec() {
            return this.exec;
        }

        @Override
        public final java.lang.String getSay() {
            return this.say;
        }

        @Override
        public final java.lang.String getSpawn() {
            return this.spawn;
        }

        @Override
        public final java.util.List<java.lang.String> getArgs() {
            return this.args;
        }

        @Override
        public final java.lang.String getCondition() {
            return this.condition;
        }

        @Override
        public final java.lang.String getCwd() {
            return this.cwd;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getEnv() {
            return this.env;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.Boolean getReceiveArgs() {
            return this.receiveArgs;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getBuiltin() != null) {
                data.set("builtin", om.valueToTree(this.getBuiltin()));
            }
            if (this.getExec() != null) {
                data.set("exec", om.valueToTree(this.getExec()));
            }
            if (this.getSay() != null) {
                data.set("say", om.valueToTree(this.getSay()));
            }
            if (this.getSpawn() != null) {
                data.set("spawn", om.valueToTree(this.getSpawn()));
            }
            if (this.getArgs() != null) {
                data.set("args", om.valueToTree(this.getArgs()));
            }
            if (this.getCondition() != null) {
                data.set("condition", om.valueToTree(this.getCondition()));
            }
            if (this.getCwd() != null) {
                data.set("cwd", om.valueToTree(this.getCwd()));
            }
            if (this.getEnv() != null) {
                data.set("env", om.valueToTree(this.getEnv()));
            }
            if (this.getName() != null) {
                data.set("name", om.valueToTree(this.getName()));
            }
            if (this.getReceiveArgs() != null) {
                data.set("receiveArgs", om.valueToTree(this.getReceiveArgs()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.TaskStep"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TaskStep.Jsii$Proxy that = (TaskStep.Jsii$Proxy) o;

            if (this.builtin != null ? !this.builtin.equals(that.builtin) : that.builtin != null) return false;
            if (this.exec != null ? !this.exec.equals(that.exec) : that.exec != null) return false;
            if (this.say != null ? !this.say.equals(that.say) : that.say != null) return false;
            if (this.spawn != null ? !this.spawn.equals(that.spawn) : that.spawn != null) return false;
            if (this.args != null ? !this.args.equals(that.args) : that.args != null) return false;
            if (this.condition != null ? !this.condition.equals(that.condition) : that.condition != null) return false;
            if (this.cwd != null ? !this.cwd.equals(that.cwd) : that.cwd != null) return false;
            if (this.env != null ? !this.env.equals(that.env) : that.env != null) return false;
            if (this.name != null ? !this.name.equals(that.name) : that.name != null) return false;
            return this.receiveArgs != null ? this.receiveArgs.equals(that.receiveArgs) : that.receiveArgs == null;
        }

        @Override
        public final int hashCode() {
            int result = this.builtin != null ? this.builtin.hashCode() : 0;
            result = 31 * result + (this.exec != null ? this.exec.hashCode() : 0);
            result = 31 * result + (this.say != null ? this.say.hashCode() : 0);
            result = 31 * result + (this.spawn != null ? this.spawn.hashCode() : 0);
            result = 31 * result + (this.args != null ? this.args.hashCode() : 0);
            result = 31 * result + (this.condition != null ? this.condition.hashCode() : 0);
            result = 31 * result + (this.cwd != null ? this.cwd.hashCode() : 0);
            result = 31 * result + (this.env != null ? this.env.hashCode() : 0);
            result = 31 * result + (this.name != null ? this.name.hashCode() : 0);
            result = 31 * result + (this.receiveArgs != null ? this.receiveArgs.hashCode() : 0);
            return result;
        }
    }
}
